# -*- coding: utf-8 -*-
from django.utils.translation import ugettext as _
from django import shortcuts

def index(request):
    response = shortcuts.render_to_response('authtkt/index.html')
    request.environ['authtkt.forget'](request, response)
    return response



# -*- coding: utf-8 -*-
from django.core.urlresolvers import reverse
from django_webtest import WebTest
from webtest import Form
from django.contrib.auth import models

__all__ = ('WebTest', 'UserWebTest', 'models', 'reverse')

class UserWebTest(WebTest):

    login = 'user1'
    extra_environ = {}

    def setUp(self):
        super(UserWebTest, self).setUp()
        user = models.User.objects.create_user(self.login, '%s@example.com' % self.login)
        user.is_staff = True
        user.set_password('xxx')
        user.save()
        self.user = user





# -*- coding: utf-8 -*-
from authtkt.tests.functionnal import *

class TestIndex(UserWebTest):

    def test_setcookie(self):
        resp = self.app.get('/admin/', user=self.login)
        cookies = resp.headers.getall('Set-Cookie')
        self.assertEqual(len([c for c in cookies if 'auth_tkt="' in c]), 1)


    def test_logout(self):
        resp = self.app.get('/admin/logout/', user=self.login)
        cookies = resp.headers.getall('Set-Cookie')
        self.assertEqual(len([c for c in cookies if 'auth_tkt="INVALID"' in c]), 1)

    def test_forget(self):
        resp = self.app.get('/authtkt/', user=self.login)
        cookies = resp.headers.getall('Set-Cookie')
        self.assertEqual(len([c for c in cookies if 'auth_tkt="INVALID"' in c]), 1)





import os, glob

# import all test_*.py files
dirname = os.path.dirname(__file__)
for filename in glob.glob(os.path.join(dirname, 'test_*.py')):
    filename = os.path.split(filename)[-1]
    mod, ext = os.path.splitext(filename)
    exec 'from %s import *' % mod



# -*- coding: utf-8 -*-
import os

try:
    from pluggableapp import PluggableApp
except ImportError:
    # pluggableapp is not installed
    pass


def pluggableapp(**kw):
    app = PluggableApp('authtkt', distribution='django-authtkt', **kw)
    app.append_app('authtkt')
    app.register_pattern('', r'^authtkt/', 'authtkt.urls')
    app.register_media(__file__)
    app.insert_templates(__file__)
    # app.initialize_settings(MYAPP_KEY='myappvalue', MYAPP_OTHER='other')
    return app




from setuptools import setup, find_packages
import sys, os

version = '0.2'

setup(name='django-authtkt',
      version=version,
      description="django-authtkt is used to share auth between more than one django site (a kind of SSO auth)",
      long_description=open('README.txt').read(),
      classifiers=[ # Get strings from http://pypi.python.org/pypi?%3Aaction=list_classifiers
          'Framework :: Django',
          'Intended Audience :: Developers',
      ],
      keywords='django auth cookie',
      author='Bearstech',
      author_email='py@beasrtech.com',
      url='https://github.com/bearstech/django-authtkt',
      license='GPL',
      packages=find_packages(exclude=['ez_setup', 'examples', 'test_project']),
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          # -*- Extra requirements: -*-
      ],
      entry_points="""
      # -*- Entry points: -*-
      [django.pluggable_app]
      authtkt = authtkt:pluggableapp
      """,
      )



# -*- coding: utf-8 -*-
from django.contrib.auth import authenticate, login
from django.contrib.auth.models import User
from django.utils import simplejson
from django.conf import settings
from authtkt.auth_tkt import AuthTktCookiePlugin
import logging

log = logging.getLogger(__name__)

def resolve(module):
    if module:
        module, meth = module.split(':')
        mod = __import__(module, {}, {}, [])
        return getattr(mod, meth)
    def empty(user):
        return user
    return empty

LOGOUT_URL = '/logout'

class AuthTktMiddleware(object):

    plugin = AuthTktCookiePlugin(settings.SECRET_KEY, **getattr(settings, 'AUTHTKT_OPTIONS', {}))
    callback = staticmethod(resolve(getattr(settings, 'AUTHTKT_CALLBACK', None)))
    cookie_type = {'domain': 1, 'subdomain':2}.get(getattr(settings, 'AUTHTKT_DOMAIN', 0), 0)

    def identify(self, request, response):
        identity = {
                'repoze.who.userid': request.user.id,
                }
        cookies = self.plugin.remember(request.environ, identity)
        header, value = cookies[self.cookie_type]
        response[header] = value
        request.environ['authtkt.processed'] = True

    def forget(self, request, response):
        cookies = self.plugin.forget(request.environ, {})
        header, value = cookies[self.cookie_type]
        response[header] = value
        request.environ['authtkt.processed'] = True

    def process_request(self, request):
        identity = self.plugin.identify(request.environ.copy())
        if identity and 'repoze.who.plugins.auth_tkt.userid' in identity:
            user_id = identity['repoze.who.plugins.auth_tkt.userid']
            try:
                user = User.objects.get(id=user_id)
            except User.DoesNotExist:
                user = User(id=user_id)
                self.callback(user)
                user.save()
            user.backend='django.contrib.auth.backends.ModelBackend'
            login(request, user)
            request.user = user
        request.environ['authtkt.identify'] = self.identify
        request.environ['authtkt.forget'] = self.forget

    def process_response(self, request, response):
        if request.environ.get('authtkt.processed', False) is not True:
            try:
                id = request.user.id
                is_anon = request.user.is_anonymous()
            except AttributeError:
                id = None
                is_anon = True
            if LOGOUT_URL in request.META['PATH_INFO']:
                self.forget(request, response)
            elif not is_anon and self.plugin.cookie_name not in request.COOKIES:
                self.identify(request, response)
        return response



